@@ -1,6 +1,8 @@
 from .utils import get_execution_time
-from .utils import update_github_file
-from .utils import download_github_file
+from .utils import get_github_repo
+from .utils import update_file
+from .utils import download_file
+from .utils import delete_file
 from .watcher import Watcher
 from .shioaji_wrapper import ShioajiWrapper
 from .aes_crypt import AESCrypt
