@@ -33,10 +33,7 @@ class AESCrypt:
         ciphertext = cipher.encrypt(data)
 
         # 回傳加密後的資料與 nonce
-        return (
-            b64encode(ciphertext).decode("utf-8"),
-            b64encode(cipher.nonce).decode("utf-8"),
-        )
+        return (b64encode(ciphertext), b64encode(cipher.nonce))
 
     def decrypt(self, data):
         """
@@ -49,4 +46,4 @@ class AESCrypt:
         cipher = AES.new(self.key, AES.MODE_CTR, nonce=nonce)
 
         # 解密資料並回傳
-        return cipher.decrypt(ciphertext).decode("utf-8")
+        return cipher.decrypt(ciphertext)
