@@ -5,38 +5,35 @@ import os
 import time
 
 
-@retry(exceptions=Exception, tries=3, delay=2, backoff=2)
-def download_github_file(token, repo_name, filename):
-    # 獲取當前工作目錄路徑
-    cwd = os.path.abspath(os.getcwd())
-
-    # 使用 token 連接 Github API
+def get_github_repo(token, repo_name):
+    """
+    連接 Github API，獲取指定名稱和 Token 的 Github 倉庫對象
+    """
     g = Github(token)
     user = g.get_user()
     repo = user.get_repo(repo_name)
+    return repo
 
-    # 獲取檔案內容
+
+@retry(exceptions=Exception, tries=3, delay=2, backoff=2)
+def download_file(repo, filename):
+    """
+    從指定的 Github 倉庫下載檔案並保存在本地
+    """
+    cwd = os.path.abspath(os.getcwd())
     file_content = repo.get_contents(filename)
     file_content_str = file_content.decoded_content.decode("utf-8")
-
-    # 寫入本地檔案
     with open(os.path.join(cwd, filename), "w") as f:
         f.write(file_content_str)
-
     print(f"{filename} downloaded")
 
 
 @retry(exceptions=Exception, tries=3, delay=2, backoff=2)
-def update_github_file(token, repo_name, filename):
-    # 獲取當前工作目錄路徑
+def update_file(repo, filename):
+    """
+    更新指定的 Github 倉庫中的檔案
+    """
     cwd = os.path.abspath(os.getcwd())
-
-    # 使用 token 連接 Github API
-    g = Github(token)
-    user = g.get_user()
-    repo = user.get_repo(repo_name)
-
-    # 獲取倉庫中所有檔案的路徑
     all_files = []
     contents = repo.get_contents("")
     while contents:
@@ -64,7 +61,38 @@ def update_github_file(token, repo_name, filename):
         print(f"{git_file} created")
 
 
+@retry(exceptions=Exception, tries=3, delay=2, backoff=2)
+def delete_file(repo, filename):
+    """
+    刪除指定的 Github 倉庫中的檔案
+    """
+    all_files = []
+    contents = repo.get_contents("")
+    while contents:
+        file_content = contents.pop(0)
+        if file_content.type == "dir":
+            contents.extend(repo.get_contents(file_content.path))
+        else:
+            file = file_content
+            all_files.append(file.path)
+
+    # 要刪除的檔案路徑
+    git_file = filename
+
+    if git_file in all_files:
+        # 如果已存在，刪除檔案
+        file = repo.get_contents(git_file)
+        repo.delete_file(file.path, "Delete files", file.sha)
+        print(f"{git_file} deleted")
+    else:
+        print(f"{git_file} does not exist.")
+
+
 def get_execution_time(func):
+    """
+    裝飾器：計算函數執行時間
+    """
+
     def wrapper(*args, **kwargs):
         start_time = time.time()
         result = func(*args, **kwargs)
